@@ -147,10 +147,8 @@ class CustomFormatter(logging.Formatter):
 class ExcludeProfilingStreamHandler(logging.StreamHandler):
 
     def emit(self, record: logging.LogRecord) -> None:
-        if record.levelname.casefold() != 'PROFILE'.casefold():
-            return super().emit(record)
-        else:
-            return
+        print(record.levelname, record.levelno)
+        return super().emit(record)
 
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
